@@ -12,9 +12,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  $Id$
  */
@@ -38,7 +37,6 @@
 #include <gtk/gtk.h>
 
 #include <panel-applet.h>
-#include <panel-applet-gconf.h>
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
@@ -51,22 +49,14 @@
 #define gettext_noop(String) (String)
 #endif
 
-#define GCONF_PATH ""
-
 static gboolean check_for_updates (gpointer data);
-static void about_cb( GtkAction *, ProgressData * );
-static void help_cb( GtkAction *, ProgressData * );
+static void about_cb( GSimpleAction *, GVariant *, gpointer );
+static void help_cb( GSimpleAction *, GVariant *, gpointer );
 
-static const GtkActionEntry battstat_menu_actions [] = {
-	{ "BattstatProperties", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (prop_cb) },
-	{ "BattstatHelp", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (help_cb) },
-	{ "BattstatAbout", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (about_cb) }
+static const GActionEntry battstat_menu_actions [] = {
+	{ "preferences", prop_cb,  NULL, NULL, NULL },
+	{ "help",        help_cb,  NULL, NULL, NULL },
+	{ "about",       about_cb, NULL, NULL, NULL }
 };
 
 #define AC_POWER_STRING _("System is running on AC power")
@@ -446,7 +436,7 @@ battery_full_dialog (GtkWidget *applet)
 			    G_OBJECT (dialog));
 
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-  hbox = gtk_hbox_new (FALSE, 6);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   pixbuf = gtk_icon_theme_load_icon (
 		gtk_icon_theme_get_default (),
 		"battery",
@@ -521,7 +511,7 @@ battery_low_update_text( ProgressData *battstat, BatteryStatus *info )
       battstat->battery_low_dialog == NULL )
     return;
 
-  gtk_widget_size_request( GTK_WIDGET( battstat->battery_low_label ), &size );
+  gtk_widget_get_preferred_size (GTK_WIDGET (battstat->battery_low_label), NULL, &size);
 
   /* If the label has never been set before, the width will be 0.  If it
      has been set before (width > 0) then we want to keep the size of
@@ -606,7 +596,7 @@ battery_low_dialog( ProgressData *battery, BatteryStatus *info )
 
   gtk_container_set_border_width (GTK_CONTAINER (battery->battery_low_dialog),
 		  6);
-  hbox = gtk_hbox_new (FALSE, 6);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
   pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
 		 "battery",
@@ -615,7 +605,7 @@ battery_low_dialog( ProgressData *battery, BatteryStatus *info )
 		 NULL);
   image = gtk_image_new_from_pixbuf (pixbuf);
   g_object_unref (pixbuf);
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 6);
   gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
   label = gtk_label_new ("");
@@ -1113,6 +1103,9 @@ destroy_applet( GtkWidget *widget, ProgressData *battstat )
   if (battstat->timeout_id)
     g_source_remove (battstat->timeout_id);
 
+  if (battstat->settings)
+    g_object_unref (battstat->settings);
+
   g_object_unref( G_OBJECT(battstat->status) );
   g_object_unref( G_OBJECT(battstat->percent) );
   g_object_unref( G_OBJECT(battstat->battery) );
@@ -1159,16 +1152,22 @@ battstat_show_help( ProgressData *battstat, const char *section )
 /* Called when the user selects the 'help' menu item.
  */
 static void
-help_cb( GtkAction *action, ProgressData *battstat )
+help_cb (GSimpleAction *action,
+         GVariant      *parameter,
+         gpointer       user_data)
 {
+  ProgressData *battstat = (ProgressData *) user_data;
   battstat_show_help( battstat, NULL );
 }
 
 /* Called when the user selects the 'about' menu item.
  */
 static void
-about_cb( GtkAction *action, ProgressData *battstat )
+about_cb (GSimpleAction *action,
+          GVariant      *parameter,
+          gpointer       user_data)
 {
+  ProgressData *battstat = (ProgressData *) user_data;
   const gchar *authors[] = {
     "J\xC3\xB6rgen Pehrson <jp@spektr.eu.org>", 
     "Lennart Poettering <lennart@poettering.de> (Linux ACPI support)",
@@ -1270,7 +1269,7 @@ size_allocate( PanelApplet *applet, GtkAllocation *allocation,
   reconfigure_layout( battstat );
 }
 
-/* Get our settings out of gconf.
+/* Get our settings out of GSettings.
  */
 static void
 load_preferences(ProgressData *battstat)
@@ -1279,11 +1278,9 @@ load_preferences(ProgressData *battstat)
 
   if (DEBUG) g_print("load_preferences()\n");
   
-  battstat->red_val = panel_applet_gconf_get_int (applet, GCONF_PATH "red_value", NULL);
+  battstat->red_val = g_settings_get_int (battstat->settings, KEY_RED_VALUE);
   battstat->red_val = CLAMP (battstat->red_val, 0, 100);
-  battstat->red_value_is_time = panel_applet_gconf_get_bool (applet,
-		  GCONF_PATH "red_value_is_time",
-		  NULL);
+  battstat->red_value_is_time = g_settings_get_boolean (battstat->settings, KEY_RED_VALUE_IS_TIME);
 
   /* automatically calculate orangle and yellow values from the red value */
   battstat->orange_val = battstat->red_val * ORANGE_MULTIPLIER;
@@ -1292,19 +1289,19 @@ load_preferences(ProgressData *battstat)
   battstat->yellow_val = battstat->red_val * YELLOW_MULTIPLIER;
   battstat->yellow_val = CLAMP (battstat->yellow_val, 0, 100);
 
-  battstat->lowbattnotification = panel_applet_gconf_get_bool (applet, GCONF_PATH "low_battery_notification", NULL);
-  battstat->fullbattnot = panel_applet_gconf_get_bool (applet, GCONF_PATH "full_battery_notification", NULL);
-  battstat->beep = panel_applet_gconf_get_bool (applet, GCONF_PATH "beep", NULL);
-  battstat->draintop = panel_applet_gconf_get_bool (applet, GCONF_PATH "drain_from_top", NULL);
+  battstat->lowbattnotification = g_settings_get_boolean (battstat->settings, KEY_LOW_BATTERY_NOTIFICATION);
+  battstat->fullbattnot = g_settings_get_boolean (battstat->settings, KEY_FULL_BATTERY_NOTIFICATION);
+  battstat->beep = g_settings_get_boolean (battstat->settings, KEY_BEEP);
+  battstat->draintop = g_settings_get_boolean (battstat->settings, KEY_DRAIN_FROM_TOP);
   
-  battstat->showstatus = panel_applet_gconf_get_bool (applet, GCONF_PATH "show_status", NULL);
-  battstat->showbattery = panel_applet_gconf_get_bool (applet, GCONF_PATH "show_battery", NULL);
+  battstat->showstatus = g_settings_get_boolean (battstat->settings, KEY_SHOW_STATUS);
+  battstat->showbattery = g_settings_get_boolean (battstat->settings, KEY_SHOW_BATTERY);
 
   /* for miagration from older versions */
   if (battstat->showstatus && battstat->showbattery)
 	  battstat->showbattery = FALSE;
   
-  battstat->showtext = panel_applet_gconf_get_int (applet, GCONF_PATH "show_text", NULL);
+  battstat->showtext = g_settings_get_int (battstat->settings, KEY_SHOW_TEXT);
 }
 
 /* Convenience function to attach a child widget to a GtkTable in the
@@ -1560,7 +1557,8 @@ battstat_applet_fill (PanelApplet *applet)
 {
   ProgressData *battstat;
   AtkObject *atk_widget;
-  GtkActionGroup *action_group;
+  GSimpleActionGroup *action_group;
+  GAction *action;
   gchar *ui_path;
   const char *err;
 
@@ -1569,15 +1567,14 @@ battstat_applet_fill (PanelApplet *applet)
   g_set_application_name (_("Battery Charge Monitor"));
 
   gtk_window_set_default_icon_name ("battery");
-  
-  panel_applet_add_preferences (applet, "/schemas/apps/battstat-applet/prefs",
-                                NULL);
+
   panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
   
   battstat = g_new0 (ProgressData, 1);
 
   /* Some starting values... */
   battstat->applet = GTK_WIDGET (applet);
+  battstat->settings = panel_applet_settings_new (applet, BATTSTAT_GSCHEMA);
   battstat->refresh_label = TRUE;
   battstat->last_batt_life = 1000;
   battstat->last_acline_status = 1000;
@@ -1598,23 +1595,24 @@ battstat_applet_fill (PanelApplet *applet)
   create_layout (battstat);
   setup_text_orientation( battstat );
 
-  action_group = gtk_action_group_new ("Battstat Applet Actions");
-  gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-  gtk_action_group_add_actions (action_group,
+  action_group = g_simple_action_group_new ();
+  g_action_map_add_action_entries (G_ACTION_MAP (action_group),
 				battstat_menu_actions,
 				G_N_ELEMENTS (battstat_menu_actions),
 				battstat);
   ui_path = g_build_filename (BATTSTAT_MENU_UI_DIR, "battstat-applet-menu.xml", NULL);
   panel_applet_setup_menu_from_file (PANEL_APPLET (battstat->applet),
-				     ui_path, action_group);
+				     ui_path, action_group,
+				     GETTEXT_PACKAGE);
   g_free (ui_path);
 
-  if (panel_applet_get_locked_down (PANEL_APPLET (battstat->applet))) {
-	  GtkAction *action;
+  gtk_widget_insert_action_group (GTK_WIDGET (applet), "battstat",
+	                              G_ACTION_GROUP (action_group));
+
+  action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "preferences");
+  g_object_bind_property (applet, "locked-down", action, "enabled",
+                          G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-	  action = gtk_action_group_get_action (action_group, "BattstatProperties");
-	  gtk_action_set_visible (action, FALSE);
-  }
   g_object_unref (action_group);
 
   atk_widget = gtk_widget_get_accessible (battstat->applet);
