@@ -323,7 +323,7 @@ get_menu_pos (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 	gint tempx, tempy, width, height;
 	gint screen_width, screen_height;
 
-	gtk_widget_size_request (GTK_WIDGET (menu), &reqmenu);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &reqmenu);
 	window = gtk_widget_get_window (curr_data->applet);
 	gdk_window_get_origin (window, &tempx, &tempy);
 	width = gdk_window_get_width (window);
@@ -369,22 +369,29 @@ chooser_button_clicked (GtkButton *button, charpick_data *curr_data)
 
 static inline void force_no_focus_padding (GtkWidget *widget)
 {
-  gboolean first_time=TRUE;
+	gboolean        first_time = TRUE;
+	GtkCssProvider *provider;
 
-  if (first_time) {
-    gtk_rc_parse_string ("\n"
-			 "   style \"charpick-applet-button-style\"\n"
-			 "   {\n"
-			 "      GtkWidget::focus-line-width=0\n"
-			 "      GtkWidget::focus-padding=0\n"
-			 "   }\n"
-			 "\n"
-			 "    widget \"*.charpick-applet-button\" style \"charpick-applet-button-style\"\n"
-			 "\n");
-    first_time = FALSE;
-  }
+	if (first_time) {
+		provider = gtk_css_provider_new ();
 
-  gtk_widget_set_name (widget, "charpick-applet-button");
+		gtk_css_provider_load_from_data (provider,
+		                                 "#charpick-applet-button {\n"
+		                                 "-GtkWidget-focus-line-width: 0px;\n"
+		                                 "-GtkWidget-focus-padding: 0px;\n"
+		                                 "}",
+		                                 -1,
+		                                 NULL);
+		gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
+		                                GTK_STYLE_PROVIDER (provider),
+		                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+		g_object_unref (provider);
+
+		first_time = FALSE;
+	}
+
+	gtk_widget_set_name (widget, "charpick-applet-button");
 }
 
 /* creates table of buttons, sets up their callbacks, and packs the table in
@@ -419,20 +426,20 @@ build_table(charpick_data *p_curr_data)
     gtk_widget_set_tooltip_text (button, _("Available palettes"));
   
     switch (panel_applet_get_orient (PANEL_APPLET (p_curr_data->applet))) {
-       	case PANEL_APPLET_ORIENT_DOWN:
-          	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
-       		break;
-       	case PANEL_APPLET_ORIENT_UP:
-          	arrow = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);  
-       		break;
-       	case PANEL_APPLET_ORIENT_LEFT:
-       		arrow = gtk_arrow_new (GTK_ARROW_LEFT, GTK_SHADOW_OUT);  
-  		break;
-       	case PANEL_APPLET_ORIENT_RIGHT:
-       		arrow = gtk_arrow_new (GTK_ARROW_RIGHT, GTK_SHADOW_OUT);  
-  		break;
-    default:
-  	  g_assert_not_reached ();
+        case PANEL_APPLET_ORIENT_DOWN:
+            arrow = gtk_image_new_from_icon_name ("pan-down-symbolic", GTK_ICON_SIZE_MENU);
+            break;
+        case PANEL_APPLET_ORIENT_UP:
+            arrow = gtk_image_new_from_icon_name ("pan-up-symbolic", GTK_ICON_SIZE_MENU);
+            break;
+        case PANEL_APPLET_ORIENT_LEFT:
+            arrow = gtk_image_new_from_icon_name ("pan-start-symbolic", GTK_ICON_SIZE_MENU);
+            break;
+        case PANEL_APPLET_ORIENT_RIGHT:
+            arrow = gtk_image_new_from_icon_name ("pan-end-symbolic", GTK_ICON_SIZE_MENU);
+            break;
+        default:
+            g_assert_not_reached ();
     }
     gtk_container_add (GTK_CONTAINER (button), arrow);
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
@@ -480,7 +487,7 @@ build_table(charpick_data *p_curr_data)
     gtk_widget_set_tooltip_text (toggle_button[i], name);
     g_free (name);
                       
-    gtk_widget_size_request (toggle_button[i], &req);
+    gtk_widget_get_preferred_size (toggle_button[i], NULL, &req);
     
     max_width = MAX (max_width, req.width);
     max_height = MAX (max_height, req.height-2);
@@ -815,7 +822,6 @@ charpicker_applet_fill (PanelApplet *applet)
 
   g_object_unref (action_group);
 
-  register_stock_for_edit ();			             
   populate_menu (curr_data);
   
   return TRUE;
