@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -25,6 +24,22 @@
 
 #define UPDATE_TIMEOUT 100
 
+static gfloat
+gtk_align_to_gfloat (GtkAlign align)
+{
+	switch (align) {
+		case GTK_ALIGN_START:
+			return 0.0;
+		case GTK_ALIGN_END:
+			return 1.0;
+		case GTK_ALIGN_CENTER:
+		case GTK_ALIGN_FILL:
+			return 0.5;
+		default:
+			return 0.0;
+	}
+}
+
 /* TODO - Optimize this a bit */
 static void 
 calculate_pupil_xy (EyesApplet *eyes_applet,
@@ -44,7 +59,9 @@ calculate_pupil_xy (EyesApplet *eyes_applet,
 	 gtk_widget_get_allocation (GTK_WIDGET(widget), &allocation);
 	 width = allocation.width;
 	 height = allocation.height;
-	 gtk_misc_get_alignment(GTK_MISC(widget),  &xalign, &yalign);
+
+	xalign = gtk_align_to_gfloat (gtk_widget_get_halign (widget));
+	yalign = gtk_align_to_gfloat (gtk_widget_get_valign (widget));
 
 	 nx = x - MAX(width - eyes_applet->eye_width, 0) * xalign - eyes_applet->eye_width / 2;
 	 ny = y - MAX(height- eyes_applet->eye_height, 0) * yalign - eyes_applet->eye_height / 2;
@@ -133,9 +150,12 @@ timer_cb (EyesApplet *eyes_applet)
 }
 
 static void
-about_cb (GtkAction   *action,
-	  EyesApplet  *eyes_applet)
+about_cb (GSimpleAction *action,
+          GVariant      *parameter,
+          gpointer       user_data)
 {
+	EyesApplet *eyes_applet = (EyesApplet *) user_data;
+
         static const gchar *authors [] = {
 		"Dave Camp <campd@oit.edu>",
 		NULL
@@ -185,7 +205,7 @@ setup_eyes (EyesApplet *eyes_applet)
 {
 	int i;
 
-        eyes_applet->hbox = gtk_hbox_new (FALSE, 0);
+        eyes_applet->hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start (GTK_BOX (eyes_applet->vbox), eyes_applet->hbox, TRUE, TRUE, 0);
 
 	eyes_applet->eyes = g_new0 (GtkWidget *, eyes_applet->num_eyes);
@@ -210,13 +230,16 @@ setup_eyes (EyesApplet *eyes_applet)
                                     0);
                 
 		if ((eyes_applet->num_eyes != 1) && (i == 0)) {
-                	gtk_misc_set_alignment (GTK_MISC (eyes_applet->eyes[i]), 1.0, 0.5);
+			gtk_widget_set_halign (eyes_applet->eyes[i], GTK_ALIGN_END);
+			gtk_widget_set_valign (eyes_applet->eyes[i], GTK_ALIGN_CENTER);
 		}
 		else if ((eyes_applet->num_eyes != 1) && (i == eyes_applet->num_eyes - 1)) {
-			gtk_misc_set_alignment (GTK_MISC (eyes_applet->eyes[i]), 0.0, 0.5);
+			gtk_widget_set_halign (eyes_applet->eyes[i], GTK_ALIGN_START);
+			gtk_widget_set_valign (eyes_applet->eyes[i], GTK_ALIGN_CENTER);
 		}
 		else {
-			gtk_misc_set_alignment (GTK_MISC (eyes_applet->eyes[i]), 0.5, 0.5);
+			gtk_widget_set_halign (eyes_applet->eyes[i], GTK_ALIGN_CENTER);
+			gtk_widget_set_valign (eyes_applet->eyes[i], GTK_ALIGN_CENTER);
 		}
 		
                 gtk_widget_realize (eyes_applet->eyes[i]);
@@ -249,7 +272,7 @@ create_eyes (PanelApplet *applet)
 	EyesApplet *eyes_applet = g_new0 (EyesApplet, 1);
 
         eyes_applet->applet = applet;
-        eyes_applet->vbox = gtk_vbox_new (FALSE, 0);
+        eyes_applet->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
 	gtk_container_add (GTK_CONTAINER (applet), eyes_applet->vbox);
 
@@ -294,9 +317,11 @@ destroy_cb (GtkWidget *object, EyesApplet *eyes_applet)
 }
 
 static void
-help_cb (GtkAction  *action,
-	 EyesApplet *eyes_applet)
+help_cb (GSimpleAction *action,
+         GVariant      *parameter,
+         gpointer       user_data)
 {
+	EyesApplet *eyes_applet = (EyesApplet *) user_data;
 	GError *error = NULL;
 
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
@@ -316,17 +341,10 @@ help_cb (GtkAction  *action,
 	}
 }
 
-
-static const GtkActionEntry geyes_applet_menu_actions [] = {
-	{ "Props", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (properties_cb) },
-	{ "Help", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (help_cb) },
-	{ "About", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (about_cb) }
+static const GActionEntry geyes_applet_menu_actions [] = {
+	{ "preferences", properties_cb, NULL, NULL, NULL },
+	{ "help",        help_cb,       NULL, NULL, NULL },
+	{ "about",       about_cb,      NULL, NULL, NULL }
 };
 
 static void
@@ -348,7 +366,8 @@ static gboolean
 geyes_applet_fill (PanelApplet *applet)
 {
 	EyesApplet *eyes_applet;
-	GtkActionGroup *action_group;
+	GSimpleActionGroup *action_group;
+	GAction *action;
 	gchar *ui_path;
 
 	g_set_application_name (_("Eyes"));
@@ -363,23 +382,25 @@ geyes_applet_fill (PanelApplet *applet)
         eyes_applet->timeout_id = g_timeout_add (
 		UPDATE_TIMEOUT, (GSourceFunc) timer_cb, eyes_applet);
 
-	action_group = gtk_action_group_new ("Geyes Applet Actions");
-	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (action_group,
-				      geyes_applet_menu_actions,
-				      G_N_ELEMENTS (geyes_applet_menu_actions),
-				      eyes_applet);
+	action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+	                                 geyes_applet_menu_actions,
+	                                 G_N_ELEMENTS (geyes_applet_menu_actions),
+	                                 eyes_applet);
 	ui_path = g_build_filename (GEYES_MENU_UI_DIR, "geyes-applet-menu.xml", NULL);
 	panel_applet_setup_menu_from_file (eyes_applet->applet,
-					   ui_path, action_group);
+					   ui_path, action_group,
+					   GETTEXT_PACKAGE);
 	g_free (ui_path);
 
-	if (panel_applet_get_locked_down (eyes_applet->applet)) {
-		GtkAction *action;
+	gtk_widget_insert_action_group (GTK_WIDGET (applet), "geyes",
+	                                G_ACTION_GROUP (action_group));
+
+	action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "preferences");
+	g_object_bind_property (applet, "locked-down",
+	                        action, "enabled",
+	                        G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-		action = gtk_action_group_get_action (action_group, "Props");
-		gtk_action_set_visible (action, FALSE);
-	}
 	g_object_unref (action_group);
 
 	gtk_widget_set_tooltip_text (GTK_WIDGET (eyes_applet->applet), _("Eyes"));
