@@ -37,16 +37,6 @@ static const GActionEntry stickynotes_applet_menu_actions [] = {
 	{ "about",       menu_about_cb,       NULL, NULL,    NULL }
 };
 
-/* Sticky Notes Icons */
-static const StickyNotesStockIcon stickynotes_icons[] =
-{
-	{ STICKYNOTES_STOCK_LOCKED, STICKYNOTES_ICONDIR "/locked.png" },
-	{ STICKYNOTES_STOCK_UNLOCKED, STICKYNOTES_ICONDIR "/unlocked.png" },
-	{ STICKYNOTES_STOCK_CLOSE, STICKYNOTES_ICONDIR "/close.png" },
-	{ STICKYNOTES_STOCK_RESIZE_SE, STICKYNOTES_ICONDIR "/resize_se.png" },
-	{ STICKYNOTES_STOCK_RESIZE_SW, STICKYNOTES_ICONDIR "/resize_sw.png" }
-};
-
 /* Sticky Notes applet factory */
 static gboolean stickynotes_applet_factory(PanelApplet *panel_applet, const gchar *iid, gpointer data)
 {
@@ -112,6 +102,35 @@ stickynotes_make_prelight_icon (GdkPixbuf *dest, GdkPixbuf *src, int shift)
 	}
 }
 
+static void
+icon_theme_changed (GtkIconTheme *icon_theme,
+                    gpointer      user_data)
+{
+	gtk_icon_theme_append_search_path (icon_theme,
+	                                   PKG_DATA_DIR G_DIR_SEPARATOR_S "icons");
+}
+
+static void
+stickynotes_applet_init_icons (void)
+{
+	GtkIconTheme *icon_theme;
+
+	icon_theme = gtk_icon_theme_get_default ();
+	icon_theme_changed (icon_theme, NULL);
+
+	g_signal_connect (gtk_icon_theme_get_default (), "changed",
+	                  G_CALLBACK (icon_theme_changed), NULL);
+}
+
+static void
+stickynotes_destroy (GtkWidget *widget,
+                     gpointer   user_dta)
+{
+	g_signal_handlers_disconnect_by_func (gtk_icon_theme_get_default (),
+	                                      icon_theme_changed, NULL);
+}
+
+
 
 /* Create and initalize global sticky notes instance */
 void
@@ -126,9 +145,6 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 
 	g_set_application_name (_("Sticky Notes"));
 
-	/* Register size for icons */
-	gtk_icon_size_register ("stickynotes_icon_size", 8,8);
-
 	gtk_window_set_default_icon_name ("gnome-sticky-notes-applet");
 
 	stickynotes->icon_normal = gtk_icon_theme_load_icon (
@@ -162,36 +178,12 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	install_check_click_on_desktop ();
 }
 
-/* Initialize Sticky Notes Icons */
-void stickynotes_applet_init_icons(void)
-{
-	GtkIconFactory *icon_factory = gtk_icon_factory_new();
-
-	gint i;
-	for (i = 0; i < G_N_ELEMENTS(stickynotes_icons); i++) {
-		StickyNotesStockIcon icon = stickynotes_icons[i];
-		GtkIconSource *icon_source = gtk_icon_source_new();
-		GtkIconSet *icon_set = gtk_icon_set_new();
-
-		gtk_icon_source_set_filename(icon_source, icon.filename);
-		gtk_icon_set_add_source(icon_set, icon_source);
-		gtk_icon_factory_add(icon_factory, icon.stock_id, icon_set);
-
-		gtk_icon_source_free(icon_source);
-		gtk_icon_set_unref(icon_set);
-	}
-
-	gtk_icon_factory_add_default(icon_factory);
-
-	g_object_unref(G_OBJECT(icon_factory));
-}
-
 void stickynotes_applet_init_prefs(void)
 {
 
 	stickynotes->builder = gtk_builder_new ();
 
-        gtk_builder_add_from_file (stickynotes->builder, BUILDER_PATH, NULL);
+        gtk_builder_add_from_file (stickynotes->builder, GTK_BUILDERDIR "/stickynotes-preferences.ui", NULL);
 
 	stickynotes->w_prefs = GTK_WIDGET (gtk_builder_get_object (stickynotes->builder,
 			"preferences_dialog"));
@@ -317,7 +309,8 @@ void stickynotes_applet_init_prefs(void)
 }
 
 /* Create a Sticky Notes applet */
-StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
+StickyNotesApplet *
+stickynotes_applet_new (PanelApplet *panel_applet)
 {
 	AtkObject *atk_obj;
 	gchar *ui_path;
@@ -380,8 +373,10 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 			G_CALLBACK(applet_change_orient_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "destroy",
 			G_CALLBACK(applet_destroy_cb), applet);
+	g_signal_connect(G_OBJECT(applet->w_applet), "destroy",
+			G_CALLBACK(stickynotes_destroy), NULL);
 
-        panel_applet_set_background_widget (panel_applet, applet->w_applet);
+	panel_applet_set_background_widget (panel_applet, applet->w_applet);
 
 	atk_obj = gtk_widget_get_accessible (applet->w_applet);
 	atk_object_set_name (atk_obj, _("Sticky Notes"));
@@ -407,6 +402,9 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 	else
 	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_normal, size, size, GDK_INTERP_BILINEAR);
 
+	if (!pixbuf1)
+		return;
+
 	/* Shift the icon if pressed */
 	pixbuf2 = gdk_pixbuf_copy(pixbuf1);
 	if (applet->pressed)
@@ -482,8 +480,8 @@ stickynotes_applet_update_prefs (void)
 			GTK_TOGGLE_BUTTON (stickynotes->w_prefs_desktop),
 			desktop_hide);
 
-	gtk_color_button_set_rgba (GTK_COLOR_BUTTON (stickynotes->w_prefs_color), &color);
-	gtk_color_button_set_rgba (GTK_COLOR_BUTTON (stickynotes->w_prefs_font_color), &font_color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (stickynotes->w_prefs_color), &color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (stickynotes->w_prefs_font_color), &font_color);
 	gtk_font_button_set_font_name (
 			GTK_FONT_BUTTON (stickynotes->w_prefs_font), font_str);
 	g_free (font_str);
@@ -517,20 +515,10 @@ stickynotes_applet_update_prefs (void)
 void stickynotes_applet_update_menus(void)
 {
 	GList *l;
-	gboolean inconsistent = FALSE;
 
 	gboolean locked = g_settings_get_boolean (stickynotes->settings, KEY_LOCKED);
 	gboolean locked_writable = g_settings_is_writable (stickynotes->settings, KEY_LOCKED);
 
-	for (l = stickynotes->notes; l != NULL; l = l->next) {
-		StickyNote *note = l->data;
-		if (note->locked != locked) {
-			inconsistent = TRUE;
-
-			break;
-		}
-	}
-
 	for (l = stickynotes->applets; l != NULL; l = l->next) {
 		StickyNotesApplet *applet = l->data;
 
